#pod test courtesy of petdance
#http://use.perl.org/comments.pl?sid=18853&cid=28930

# $Id: 00.load.t 1347 2004-05-26 09:10:20Z jonasbn $

use Test::More tests => 1;

BEGIN { use_ok( 'Date::Holidays::Super' ); }
